@@ -56,8 +56,10 @@ bool gcpGroup::BuildContextualMenu (GtkUIManager *UIManager, Object *object, dou
 	GtkAction *action = gtk_action_new ("group_properties", _("Group properties..."), NULL, NULL);
 	g_signal_connect_swapped (action, "activate", G_CALLBACK (on_group_properties), this);
 	gtk_action_group_add_action (group, action);
+	g_object_unref (action);
 	gtk_ui_manager_add_ui_from_string (UIManager, "<ui><popup><menuitem action='group_properties'/></popup></ui>", -1, NULL);
 	gtk_ui_manager_insert_action_group (UIManager, group, 0);
+	g_object_unref (group);
 	GetParent ()->BuildContextualMenu (UIManager, object, x, y);
 	return true;
 }
@@ -264,6 +266,7 @@ bool gcpGroup::Load (xmlNodePtr node)
 					m_Spaced = true;
 				xmlFree (buf);
 			}
+			((gcpDocument*) GetDocument ())->GetView ()->AddObject (this);
 			gcpWidgetData  *pData= (gcpWidgetData*) g_object_get_data (G_OBJECT (((gcpDocument*) GetDocument ())->GetWidget ()), "data");
 			gnome_canvas_update_now (GNOME_CANVAS (pData->Canvas));
 			Align ();
@@ -341,3 +344,14 @@ double gcpGroup::GetYAlign ()
 	pData->GetObjectBounds (this, &rect);
 	return (rect.y1 - rect.y0) / 2.;
 }
+
+void gcpGroup::Add (GtkWidget* w)
+{
+	map<string, Object*>::iterator i;
+	Object* p = GetFirstChild (i);
+	while (p)
+	{
+		p->Add (w);
+		p = GetNextChild (i);
+	}
+}
